@@ -147,6 +147,11 @@ GST_PAD_TEMPLATE_FACTORY (src_audio_templ,
     "audio/x-mp3",
       NULL
   ),
+  GST_CAPS_NEW (
+    "avidemux_src_audio",
+    "audio/a52",
+      NULL
+  ),
   GST_CAPS_NEW (
     "avidemux_src_audio",
     "application/x-ogg",
@@ -169,9 +174,9 @@ static const GstEventMask*
 			gst_avi_demux_get_event_mask 		(GstPad *pad);
 static gboolean 	gst_avi_demux_handle_src_event 		(GstPad *pad, GstEvent *event);
 static const GstFormat* gst_avi_demux_get_src_formats 		(GstPad *pad); 
-static const GstPadQueryType*
+static const GstQueryType*
 			gst_avi_demux_get_src_query_types 	(GstPad *pad);
-static gboolean 	gst_avi_demux_handle_src_query 		(GstPad *pad, GstPadQueryType type, 
+static gboolean 	gst_avi_demux_handle_src_query 		(GstPad *pad, GstQueryType type, 
 								 GstFormat *format, gint64 *value);
 static gboolean 	gst_avi_demux_src_convert 		(GstPad *pad, GstFormat src_format, gint64 src_value,
 	        	          				 GstFormat *dest_format, gint64 *dest_value);
@@ -380,6 +385,17 @@ gst_avi_demux_strh (GstAviDemux *avi_demux)
   return FALSE;
 }
 
+static void
+gst_avi_demux_dmlh (GstAviDemux *avi_demux)
+{
+  gst_riff_dmlh *dmlh;
+  guint32 got_bytes;
+
+  got_bytes = gst_bytestream_peek_bytes (avi_demux->bs, (guint8**) &dmlh, sizeof (gst_riff_dmlh));
+
+/*   g_print ("Found total frame: %u\n", dmlh->totalframes); */
+}
+
 static void 
 gst_avi_demux_strf_vids (GstAviDemux *avi_demux)
 {
@@ -549,6 +565,14 @@ gst_avi_demux_strf_auds (GstAviDemux *avi_demux)
                               "application/x-ogg",
                               NULL);
       break;
+    case GST_RIFF_WAVE_FORMAT_A52:
+      newcaps = gst_caps_new ("avidemux_audio_src",
+                              "audio/a52",
+                              NULL);
+      break;
+    default:
+      g_warning ("avidemux: unkown audio format %d", GUINT16_FROM_LE(strf->format));
+      break;
   }
 
   if (newcaps) capslist = gst_caps_append(capslist, newcaps);
@@ -872,12 +896,12 @@ gst_avi_demux_src_convert (GstPad *pad, GstFormat src_format, gint64 src_value,
   return res;
 }
 
-static const GstPadQueryType*
+static const GstQueryType*
 gst_avi_demux_get_src_query_types (GstPad *pad) 
 {
-  static const GstPadQueryType src_types[] = {
-    GST_PAD_QUERY_TOTAL,
-    GST_PAD_QUERY_POSITION,
+  static const GstQueryType src_types[] = {
+    GST_QUERY_TOTAL,
+    GST_QUERY_POSITION,
     0
   };
 
@@ -885,7 +909,7 @@ gst_avi_demux_get_src_query_types (GstPad *pad)
 }
 
 static gboolean
-gst_avi_demux_handle_src_query (GstPad *pad, GstPadQueryType type, 
+gst_avi_demux_handle_src_query (GstPad *pad, GstQueryType type, 
 				GstFormat *format, gint64 *value)
 {
   gboolean res = TRUE;
@@ -893,7 +917,7 @@ gst_avi_demux_handle_src_query (GstPad *pad, GstPadQueryType type,
   avi_stream_context *stream = gst_pad_get_element_private (pad);
 
   switch (type) {
-    case GST_PAD_QUERY_TOTAL:
+    case GST_QUERY_TOTAL:
       switch (*format) {
         case GST_FORMAT_DEFAULT:
           *format = GST_FORMAT_TIME;
@@ -921,7 +945,7 @@ gst_avi_demux_handle_src_query (GstPad *pad, GstPadQueryType type,
 	  break;
       }
       break;
-    case GST_PAD_QUERY_POSITION:
+    case GST_QUERY_POSITION:
       switch (*format) {
         case GST_FORMAT_DEFAULT:
           *format = GST_FORMAT_TIME;
@@ -1173,6 +1197,7 @@ gst_avi_demux_read_chunk (GstAviDemux *avi_demux, guint32 *id, guint32 *size)
 
       return TRUE;
     }
+
   } while (gst_avi_demux_handle_sink_event (avi_demux));
 
   return TRUE;
@@ -1257,8 +1282,9 @@ gst_avi_demux_process_chunk (GstAviDemux *avi_demux, guint64 *filepos,
             gst_bytestream_get_status (avi_demux->bs, &remaining, &event);
 	    gst_event_unref (event);
 	  }
-	  if  (avi_demux->avih.bufsize)
+	  if  (avi_demux->avih.bufsize) {
 	    gst_bytestream_size_hint (avi_demux->bs, avi_demux->avih.bufsize);
+	  }
 
 	  gst_avi_demux_process_movi (avi_demux, rec_depth, filepos);
 	  goto done;
@@ -1332,7 +1358,7 @@ gst_avi_demux_process_chunk (GstAviDemux *avi_demux, guint64 *filepos,
       avi_stream_context *stream;
       gint64 next_ts;
       GstFormat format;
-      
+
       stream_id = CHUNKID_TO_STREAMNR (chunkid);
 		   
       stream = &avi_demux->stream[stream_id];
@@ -1341,7 +1367,7 @@ gst_avi_demux_process_chunk (GstAviDemux *avi_demux, guint64 *filepos,
 		    chunkid, *chunksize, stream_id);
 
       format = GST_FORMAT_TIME;
-      gst_pad_query (stream->pad, GST_PAD_QUERY_POSITION, &format, &next_ts);
+      gst_pad_query (stream->pad, GST_QUERY_POSITION, &format, &next_ts);
 
       if (stream->strh.init_frames == stream->current_frame && stream->delay==0)
 	stream->delay = next_ts;
@@ -1384,17 +1410,31 @@ gst_avi_demux_process_chunk (GstAviDemux *avi_demux, guint64 *filepos,
       *chunksize = (*chunksize + 1) & ~1;
       break;
     }
-    default:
-      GST_DEBUG (0, "  *****  unknown chunkid %08x (%s)", chunkid, gst_riff_id_to_fourcc (chunkid));
-      *chunksize = (*chunksize + 1) & ~1;
-      break;
+  case GST_RIFF_TAG_dmlh:
+    gst_avi_demux_dmlh (avi_demux);
+    break;
+    
+  case GST_RIFF_TAG_JUNK:
+  case GST_RIFF_ISFT:
+    *chunksize = (*chunksize + 1) & ~1;
+    break;
+    
+  default:
+    GST_DEBUG (0, "  *****  unknown chunkid %08x", chunkid);
+    *chunksize = 1;
+/*       *chunksize = (*chunksize + 1) & ~1; */
   }
   GST_INFO (GST_CAT_PLUGIN_INFO, "chunkid %s, flush %08x, filepos %08llx", 
-		  gst_riff_id_to_fourcc (chunkid), *chunksize, *filepos);
-
+	    gst_riff_id_to_fourcc (chunkid), *chunksize, *filepos);
+  
   *filepos += *chunksize;
-  if (!gst_bytestream_flush (bs, *chunksize)) {
-    return gst_avi_demux_handle_sink_event (avi_demux);
+  {
+    gboolean ret;
+    
+    ret = gst_bytestream_flush (bs, *chunksize);
+    if (!ret) {
+      return gst_avi_demux_handle_sink_event (avi_demux);
+    }
   }
 
 done:
