@@ -80,12 +80,13 @@ GST_PAD_TEMPLATE_FACTORY (int2float_sink_factory,
 static void                 gst_int2float_class_init (GstInt2FloatClass *klass);
 static void                 gst_int2float_init (GstInt2Float *plugin);
 
-static GstPadConnectReturn  gst_int2float_connect (GstPad *pad, GstCaps *caps);
+static GstPadLinkReturn  gst_int2float_connect (GstPad *pad, GstCaps *caps);
 
 static void                 gst_int2float_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
 static void                 gst_int2float_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
 static GstPad*              gst_int2float_request_new_pad (GstElement *element, GstPadTemplate *temp, const gchar *unused);
 static void                 gst_int2float_chain_gint16 (GstPad *pad, GstBuffer *buf_in);
+static GstElementStateReturn gst_int2float_change_state (GstElement *element);
 static inline GstInt2Float* gst_int2float_get_plugin (GstPad *pad,GstBuffer *buf);
 
 static GstPadTemplate  *srctempl, *sinktempl;
@@ -125,6 +126,7 @@ gst_int2float_class_init (GstInt2FloatClass *klass)
   gobject_class->set_property = gst_int2float_set_property;
   gobject_class->get_property = gst_int2float_get_property;
   gstelement_class->request_new_pad = gst_int2float_request_new_pad;
+  gstelement_class->change_state = gst_int2float_change_state;
 }
 
 static void
@@ -135,7 +137,7 @@ gst_int2float_init (GstInt2Float *plugin)
   gst_element_add_pad(GST_ELEMENT(plugin),plugin->sinkpad);
   gst_pad_set_chain_function(plugin->sinkpad,gst_int2float_chain_gint16);
   
-  gst_pad_set_connect_function(plugin->sinkpad, gst_int2float_connect);
+  gst_pad_set_link_function(plugin->sinkpad, gst_int2float_connect);
 
   plugin->numsrcpads = 0;
   plugin->srcpads = NULL;
@@ -146,7 +148,7 @@ gst_int2float_init (GstInt2Float *plugin)
 }
 
 /* see notes in gstfloat2int.c */
-static GstPadConnectReturn
+static GstPadLinkReturn
 gst_int2float_connect (GstPad *pad, GstCaps *caps)
 {
   GstInt2Float *filter;
@@ -167,17 +169,17 @@ gst_int2float_connect (GstPad *pad, GstCaps *caps)
 
         filter->in_capsnego = TRUE;
 
-        for (l=filter->srcpads; l; l=l->next)
-          if (gst_pad_try_set_caps ((GstPad*) l->data, floatcaps) <= 0)
-            return GST_PAD_CONNECT_REFUSED;
-        
-        filter->in_capsnego = FALSE;
-
-        /* FIXME: refcounting? */
+	/* FIXME: refcounting? */
         filter->floatcaps = floatcaps;
         filter->intcaps = caps;
         gst_caps_get_int (caps, "channels", &filter->channels);
-        return GST_PAD_CONNECT_OK;
+    
+        for (l=filter->srcpads; l; l=l->next)
+          if (gst_pad_try_set_caps ((GstPad*) l->data, floatcaps) <= 0)
+            return GST_PAD_LINK_REFUSED;
+        
+        filter->in_capsnego = FALSE;
+        return GST_PAD_LINK_OK;
       } else { 
         gst_caps_set (filter->intcaps, "channels", GST_PROPS_INT_RANGE (1, G_MAXINT));
         filter->intcaps->fixed = FALSE;
@@ -186,12 +188,12 @@ gst_int2float_connect (GstPad *pad, GstCaps *caps)
           gst_caps_set (filter->intcaps, "channels", GST_PROPS_INT (filter->channels));
           filter->intcaps->fixed = TRUE;
           filter->intcaps->properties->fixed = TRUE;
-          return GST_PAD_CONNECT_OK;
+          return GST_PAD_LINK_OK;
         } else {
           gst_caps_set (filter->intcaps, "channels", GST_PROPS_INT (filter->channels));
           filter->intcaps->fixed = TRUE;
           filter->intcaps->properties->fixed = TRUE;
-          return GST_PAD_CONNECT_REFUSED;
+          return GST_PAD_LINK_REFUSED;
         }
       }
     } else {
@@ -205,9 +207,9 @@ gst_int2float_connect (GstPad *pad, GstCaps *caps)
            capsnego reached the end and bounced back to float2int, that started
            setting all of its sink pads, which brought me back here. */
         if (rate == filter->rate)
-          return GST_PAD_CONNECT_OK;
+          return GST_PAD_LINK_OK;
         else
-          return GST_PAD_CONNECT_REFUSED;
+          return GST_PAD_LINK_REFUSED;
       }
 
       intcaps = gst_caps_copy (gst_pad_template_get_caps (int2float_sink_factory ()));
@@ -226,12 +228,12 @@ gst_int2float_connect (GstPad *pad, GstCaps *caps)
           gst_caps_debug (gottencaps, "gotten_caps");
           newcaps = gst_caps_intersect (gottencaps, intcaps);
           if (!newcaps)
-            return GST_PAD_CONNECT_REFUSED;
+            return GST_PAD_LINK_REFUSED;
           
           if (GST_CAPS_IS_FIXED (newcaps)) {
             gst_caps_get_int (newcaps, "channels", &filter->channels);
             if (gst_pad_try_set_caps (filter->sinkpad, newcaps) <= 0)
-              return GST_PAD_CONNECT_DELAYED;
+              return GST_PAD_LINK_DELAYED;
           }
 
           filter->intcaps = newcaps;
@@ -243,26 +245,26 @@ gst_int2float_connect (GstPad *pad, GstCaps *caps)
           filter->channels = filter->numsrcpads;
         
           if (gst_pad_try_set_caps (filter->sinkpad, intcaps) <= 0)
-            return GST_PAD_CONNECT_REFUSED;
+            return GST_PAD_LINK_REFUSED;
 
           filter->intcaps = intcaps;
         }
         
         for (l=filter->srcpads; l; l=l->next)
           if (! ((GstPad*) l->data == pad || gst_pad_try_set_caps ((GstPad*) l->data, caps) > 0))
-            return GST_PAD_CONNECT_REFUSED;
+            return GST_PAD_LINK_REFUSED;
         
         /* FIXME: refcounting? */
         filter->floatcaps = caps;
-        return GST_PAD_CONNECT_OK;
+        return GST_PAD_LINK_OK;
       } else if (gst_caps_intersect (intcaps, filter->intcaps)) {
-        return GST_PAD_CONNECT_OK;
+        return GST_PAD_LINK_OK;
       } else {
-        return GST_PAD_CONNECT_REFUSED;
+        return GST_PAD_LINK_REFUSED;
       }
     }
   } else {
-    return GST_PAD_CONNECT_DELAYED;
+    return GST_PAD_LINK_DELAYED;
   }
 }
 
@@ -283,11 +285,11 @@ gst_int2float_request_new_pad (GstElement *element, GstPadTemplate *templ, const
     return NULL;
   }
 
-  name = g_strdup_printf ("src%d",plugin->numsrcpads);
+  name = g_strdup_printf ("src%d", plugin->numsrcpads);
   srcpad = gst_pad_new_from_template (templ, name);
   g_free (name);
   gst_element_add_pad (GST_ELEMENT (plugin), srcpad);
-  gst_pad_set_connect_function (srcpad, gst_int2float_connect);
+  gst_pad_set_link_function (srcpad, gst_int2float_connect);
   
   plugin->srcpads = g_slist_append (plugin->srcpads, srcpad);
   plugin->numsrcpads++;
@@ -391,6 +393,30 @@ gst_int2float_get_property (GObject *object, guint prop_id, GValue *value, GPara
   }
 }
 
+static GstElementStateReturn
+gst_int2float_change_state (GstElement *element)
+{
+  GstInt2Float *plugin;
+
+  plugin = GST_INT2FLOAT (element);
+  
+  switch (GST_STATE_TRANSITION (element)) {
+  case GST_STATE_PAUSED_TO_READY:
+    plugin->intcaps = NULL;
+    plugin->floatcaps = NULL;
+    break;
+
+  default:
+    break;
+  }
+
+  if (GST_ELEMENT_CLASS (parent_class)->change_state) 
+    return GST_ELEMENT_CLASS (parent_class)->change_state (element);
+
+  return GST_STATE_SUCCESS;
+
+}
+
 gboolean 
 gst_int2float_factory_init (GstPlugin *plugin) 
 {
