@@ -68,6 +68,7 @@ static void		gst_xvideosink_set_clock	(GstElement *element, GstClock *clock);
 static GstElementStateReturn
 			gst_xvideosink_change_state 	(GstElement *element);
 
+static gboolean		gst_xvideosink_release_locks	(GstElement *element);
 static void		gst_xvideosink_set_property	(GObject *object, guint prop_id, 
 							 const GValue *value, GParamSpec *pspec);
 static void		gst_xvideosink_get_property	(GObject *object, guint prop_id, 
@@ -159,6 +160,7 @@ gst_xvideosink_class_init (GstXVideoSinkClass *klass)
   
   gstelement_class->change_state = gst_xvideosink_change_state;
   gstelement_class->set_clock = gst_xvideosink_set_clock;
+  gstelement_class->release_locks = gst_xvideosink_release_locks;
 
 }
 
@@ -187,7 +189,8 @@ gst_xvideosink_buffer_pool_free (GstBufferPool *pool)
 }
 
 static GstBuffer*
-gst_xvideosink_buffer_new (GstBufferPool *pool, guint64 location, guint size, gpointer user_data)
+gst_xvideosink_buffer_new (GstBufferPool *pool,  
+		           gint64 location, guint size, gpointer user_data)
 {
   GstXVideoSink *xvideosink;
   GstBuffer *buffer;
@@ -221,6 +224,11 @@ gst_xvideosink_buffer_new (GstBufferPool *pool, guint64 location, guint size, gp
     xvideosink->image_pool = g_slist_delete_link (xvideosink->image_pool, xvideosink->image_pool);
     g_mutex_unlock (xvideosink->pool_lock);
   }
+  if (image == NULL) {
+    gst_element_error(GST_ELEMENT (xvideosink), "image creation failed");
+    /* FIXME: need better error handling here */
+    return NULL;
+  }
 
   buffer = gst_buffer_new ();
   GST_BUFFER_POOL_PRIVATE (buffer) = image;
@@ -291,9 +299,9 @@ gst_xvideosink_get_bufferpool (GstPad *pad)
     xvideosink->bufferpool = gst_buffer_pool_new (
 		    NULL,		/* free */
 		    NULL,		/* copy */
-		    gst_xvideosink_buffer_new,
+		    (GstBufferPoolBufferNewFunction)gst_xvideosink_buffer_new,
 		    NULL,		/* buffer copy, the default is fine */
-		    gst_xvideosink_buffer_free,
+		    (GstBufferPoolBufferFreeFunction)gst_xvideosink_buffer_free,
 		    xvideosink);
 
     xvideosink->image_pool = NULL;
@@ -325,7 +333,7 @@ gst_xvideosink_get_real_size (GstXVideoSink *xvideosink,
   }
 }
 
-static GstPadConnectReturn
+static GstPadLinkReturn
 gst_xvideosink_sinkconnect (GstPad *pad, GstCaps *caps)
 {
   GstXVideoSink *xvideosink;
@@ -335,7 +343,7 @@ gst_xvideosink_sinkconnect (GstPad *pad, GstCaps *caps)
 
   /* we are not going to act on variable caps */
   if (!GST_CAPS_IS_FIXED (caps))
-    return GST_PAD_CONNECT_DELAYED;
+    return GST_PAD_LINK_DELAYED;
 
   gst_caps_get (caps, 
 		  "format", &xvideosink->format,
@@ -375,11 +383,10 @@ gst_xvideosink_sinkconnect (GstPad *pad, GstCaps *caps)
     xvideosink->image = GST_IMAGE (_gst_ximage_new ( 
 		      xvideosink->window, 
 		      xvideosink->width, xvideosink->height));
-  }
-  else {
+  } else {
     if (xvideosink->disable_xv) {
       g_mutex_unlock (xvideosink->lock);
-      return GST_PAD_CONNECT_REFUSED;
+      return GST_PAD_LINK_REFUSED;
     }
 
     xvideosink->image = GST_IMAGE (_gst_xvimage_new ( 
@@ -388,6 +395,12 @@ gst_xvideosink_sinkconnect (GstPad *pad, GstCaps *caps)
 		      xvideosink->width, xvideosink->height));
   }
 
+  if (xvideosink->image == NULL) {
+    /* FIXME: need better error handling? */
+    gst_element_error (GST_ELEMENT (xvideosink), "image creation failed");
+    return GST_PAD_LINK_REFUSED;
+  }
+
   g_mutex_unlock (xvideosink->lock);
 
   {
@@ -402,7 +415,7 @@ gst_xvideosink_sinkconnect (GstPad *pad, GstCaps *caps)
 		    real_x, real_y);
   }
 
-  return GST_PAD_CONNECT_OK;
+  return GST_PAD_LINK_OK;
 }
 
 static GstCaps *
@@ -421,7 +434,7 @@ gst_xvideosink_init (GstXVideoSink *xvideosink)
   xvideosink->sinkpad = gst_pad_new_from_template (sink_template, "sink");
   gst_element_add_pad (GST_ELEMENT (xvideosink), xvideosink->sinkpad);
   gst_pad_set_chain_function (xvideosink->sinkpad, gst_xvideosink_chain);
-  gst_pad_set_connect_function (xvideosink->sinkpad, gst_xvideosink_sinkconnect);
+  gst_pad_set_link_function (xvideosink->sinkpad, gst_xvideosink_sinkconnect);
   gst_pad_set_getcaps_function (xvideosink->sinkpad, gst_xvideosink_getcaps);
   gst_pad_set_bufferpool_function (xvideosink->sinkpad, gst_xvideosink_get_bufferpool);
 
@@ -496,8 +509,7 @@ gst_xvideosink_chain (GstPad *pad, GstBuffer *buf)
       case GST_EVENT_DISCONTINUOUS:
 	offset = GST_EVENT_DISCONT_OFFSET (event, 0).value;
 	g_print ("xvideo discont %lld\n", offset);
-	gst_clock_handle_discont (xvideosink->clock, 
-			          (guint64) GST_EVENT_DISCONT_OFFSET (event, 0).value);
+	gst_clock_handle_discont (xvideosink->clock, (guint64) offset);
 	break;
       default:
 	gst_pad_event_default (pad, event);
@@ -510,12 +522,14 @@ gst_xvideosink_chain (GstPad *pad, GstBuffer *buf)
   if (xvideosink->clock && time != -1) {
     GstClockReturn ret;
 
+    xvideosink->id = gst_clock_new_single_shot_id (xvideosink->clock, time);
+
     GST_DEBUG (0,"videosink: clock %s wait: %llu %u\n", 
 		  GST_OBJECT_NAME (xvideosink->clock), time, GST_BUFFER_SIZE (buf));
 
-    ret = gst_element_clock_wait (GST_ELEMENT (xvideosink),
-		    xvideosink->clock, time - xvideosink->correction, &jitter);
-
+    ret = gst_clock_id_wait (xvideosink->id, &jitter);
+    gst_clock_id_free (xvideosink->id);
+    xvideosink->id = NULL;
   }
   if (xvideosink->clock)
     time = gst_clock_get_time (xvideosink->clock);
@@ -601,7 +615,7 @@ gst_xvideosink_set_property (GObject *object, guint prop_id,
       xvideosink->auto_size = g_value_get_boolean (value);
       break;
     case ARG_NEED_NEW_WINDOW:
-      if (g_value_get_boolean (value)){
+      if (g_value_get_boolean (value)) {
         g_mutex_lock (xvideosink->lock);
         /* FIXME destroying the window causes a crash, so we'll let it leak for now */
         /*_gst_xwindow_destroy (xvideosink->window);*/
@@ -609,7 +623,10 @@ gst_xvideosink_set_property (GObject *object, guint prop_id,
 			                       xvideosink->height, 
 					       xvideosink->toplevel);
         if (!xvideosink->window) {
-          g_warning ("could not create X window\n");
+	  gst_element_error (GST_ELEMENT (xvideosink), "could not create X window");
+	  /* FIXME: could use better error handling here */
+          g_mutex_unlock (xvideosink->lock);
+	  break;
         }
         xvideosink->send_xid = TRUE;
         xvideosink->need_new_window = FALSE;
@@ -758,6 +775,20 @@ gst_xvideosink_change_state (GstElement *element)
   return GST_STATE_SUCCESS;
 }
 
+static gboolean
+gst_xvideosink_release_locks (GstElement *element)
+{
+  GstXVideoSink *xvideosink;
+
+  xvideosink = GST_XVIDEOSINK (element);
+
+  if (xvideosink->id) {
+    gst_clock_id_unlock (xvideosink->id);
+  }
+
+  return TRUE;
+}
+
 static gboolean
 plugin_init (GModule *module, GstPlugin *plugin)
 {
